#!/System/Library/Frameworks/Ruby.framework/Versions/1.8/usr/bin/ruby

require 'osx/cocoa'
include OSX

libraryDirectoryPath = File.dirname(__FILE__)
$LOAD_PATH << libraryDirectoryPath

require 'xcarchive.rb'

def usage
	print "Usage:\n"
	print "-archivePath: path to the xcarchive bundle to be extracted [required]\n"
	print "-destinationPath: path to a directory the bundle should be copied [required]\n"
	print "\n"
	print "Example:\n"
	print "ruby xcarchive_extract.rb\n -archivePath ~/Projects/Build\\ Archive/Courier/Courier_4770_1.2.1rc1-appstore.xcarchive -out ~/Desktop\n"
	print "\n"
	exit 1
end

if ARGV.count == 0
	usage
end

def start
	print "============ ARCHIVE EXTRACTION STARTED ============\n"
	print "\n"
end

def fail(reason)
	print "\n"
	print "============ ARCHIVE EXTRACTION FAILURE ============\n"
	print "\n"
	print "error: #{reason}\n"
	print "\n"
	exit 1
end

def finish
	print "\n"
	print "============ ARCHIVE EXTRACTION SUCCESS ============\n"
end


# Check arguments

archivePath = NSUserDefaults.standardUserDefaults.stringForKey "archivePath"
if archivePath.nil?
	fail "an archivePath must be specified using -archivePath"
	exit 1
end
unless NSFileManager.defaultManager.fileExistsAtPath archivePath
	fail "archive does not exist at the specified path"
	exit 1
end

destinationPath = NSUserDefaults.standardUserDefaults.stringForKey "destinationPath"
if destinationPath.nil?
	fail "a destination directory path must be specified using -destinationPath"
end
destinationPathExists = NSFileManager.defaultManager.fileExistsAtPath_isDirectory destinationPath
unless destinationPathExists[0] && destinationPathExists[1]
	fail "destinationPath must exist and be a directory"
	exit 1
end


#

archive = Xcarchive.new
applicationLocation, applicationLocationError = archive.readApplicationLocationInArchiveAtLocationWithError NSURL.fileURLWithPath(archivePath)
fail "couldn't extract xcarchive, #{applicationLocationError.localizedDescription}" unless applicationLocation

copyDestinationLocation = NSURL.fileURLWithPath(destinationPath).URLByAppendingPathComponent(applicationLocation.lastPathComponent)
fail "a product exists at the copyDestinationPath #{copyDestinationLocation.path}" if NSFileManager.defaultManager.fileExistsAtPath copyDestinationLocation.path


#

start


#

copied = NSFileManager.defaultManager.copyItemAtURL_toURL_error(applicationLocation, copyDestinationLocation)
fail "couldn't copy to destinationPath #{copied[1]} #{copied[1].localizedDescription}" unless copied[0]


#

finish
