#!/System/Library/Frameworks/Ruby.framework/Versions/1.8/usr/bin/ruby

require 'osx/cocoa'
include OSX

libraryDirectoryPath = File.dirname(__FILE__)
$LOAD_PATH << libraryDirectoryPath

require 'xcarchive.rb'
require 'codesign.rb'
require 'bundle.rb'

def usage
	print "Usage:\n"
	print "-archivePath: path to the xcarchive bundle to be passed to productbuild [required]\n"
	print "-packagePath: path to write the Product.pkg file to [required]\n"
	print "\n"
	print "Example:\n"
	print "ruby xcarchive_productbuild.rb\n -archivePath ~/Projects/Build\\ Archive/Courier/Courier_4770_1.2.1rc1-appstore.xcarchive -packagePath ~/Desktop/Courier.pkg\n"
	print "\n"
	exit 1
end

if ARGV.count == 0
	usage
end

def start
	
end

def fail(reason)
	print "\n"
	print "============    PRODUCTBUILD FAILURE    ============\n"
	print "\n"
	print "error: #{reason}\n"
	print "\n"
	exit 1
end

def finish
	print "\n"
	print "============    PRODUCTBUILD SUCCESS    ============\n"
end


# Check arguments

archivePath = NSUserDefaults.standardUserDefaults.stringForKey "archivePath"
if archivePath.nil?
	fail "an archivePath must be specified using -archivePath"
end
unless NSFileManager.defaultManager.fileExistsAtPath archivePath
	fail "archive does not exist at the specified path"
end

packagePath = NSUserDefaults.standardUserDefaults.objectForKey "packagePath"
if packagePath.nil?
	fail "a packagePath must be specified using -packagePath"
	exit 1
end
if NSFileManager.defaultManager.fileExistsAtPath packagePath
	fail "a package already exists at the specified packagePath"
	exit 1
end


#

start


# Find the application bundle in the xcarchive

xcarchive = Xcarchive.new
applicationLocation, applicationLocationError = xcarchive.readApplicationLocationInArchiveAtLocationWithError NSURL.fileURLWithPath(archivePath)
fail "couldn't build xcarchive, #{applicationLocationError.localizedDescription}" if applicationLocation.nil?


# Generate the package

$stdout.flush
applicationProductbuildTask = NSTask.launchedTaskWithLaunchPath_arguments_ File.join(libraryDirectoryPath, "application_productbuild.rb"), [ "-applicationPath", applicationLocation.path, "-packagePath", packagePath ].to_ns
applicationProductbuildTask.waitUntilExit

fail "application_productbuild failed" unless applicationProductbuildTask.terminationStatus == 0


#

finish
